@@ -36,7 +36,7 @@ class Ks3Oss:
 
     def save(self, key, bucket_name="", content_type="string", protocol="https", domain="ksyun.com",
              region="ks3-cn-beijing", **kwargs):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         k = self.instance.new_key(key)
         ret = None
@@ -57,7 +57,7 @@ class Ks3Oss:
             return False
 
     def get_url(self, key, bucket_name="", region="ks3-cn-beijing", domain="ksyun.com", protocol="https"):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         if self.instance.get_key(key):
             return f'{protocol}://{bucket_name}.{region}.{domain}/{key}'
@@ -65,7 +65,7 @@ class Ks3Oss:
             return None
 
     def get_file(self, key, bucket_name="", file_path=None):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         k = self.instance.get_key(key)
         if file_path:
@@ -76,19 +76,19 @@ class Ks3Oss:
             return contents
 
     def get_key(self, key, bucket_name=""):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         k = self.instance.get_key(key)
         return k
 
     def delete_file(self, key, bucket_name=None):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         res = self.instance.delete_key(key)
         return res
 
     def list_file(self, bucket_name, delimiter="/"):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         keys = self.instance.list(delimiter=delimiter)
         files = list()
@@ -109,34 +109,34 @@ class Ks3Oss:
         return dirs, files
 
     def get_bucket_acl(self, bucket_name=None):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         acl = self.instance.get_acl()
         return acl
 
     def set_bucket_acl(self, bucket_name=None, *args, **kwargs):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         return self.instance.set_acl(*args, **kwargs)
 
     def get_bucket_policy(self, bucket_name=None):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         policy = self.instance.get_bucket_policy()
         return policy
 
     def set_bucket_policy(self, policy, bucket_name=None, headers=None):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         return self.instance.set_bucket_policy(policy, headers)
 
     def delete_bucket_policy(self, bucket_name=None, headers=None):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         return self.instance.delete_bucket_policy(headers)
 
     def multipart_upload(self, file_path, chunk_size, bucket_name=None, **kwargs):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         file_size = os.stat(file_path).st_size
         mp = self.instance.initiate_multipart_upload(os.path.basename(file_path), **kwargs)
@@ -150,18 +150,18 @@ class Ks3Oss:
         return ret
 
     def list_multipart_upload_parts(self, key, bucket_name=None, **kwargs):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         mp = self.instance.initiate_multipart_upload(key, **kwargs)
         return mp.get_all_parts()
 
     def list_multipart_uploads(self, key, bucket_name=None, **kwargs):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         return self.instance.list_multipart_uploads(key, **kwargs)
 
     def generate_url(self, key, second, bucket_name=None):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         k = self.instance.get_key(key)
         if k:
@@ -171,7 +171,7 @@ class Ks3Oss:
             return None
 
     def get_presigned_url(self, key, second, bucket_name=None, expires_in_absolute=False):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         k = self.instance.new_key(key)
         if k:
@@ -181,6 +181,6 @@ class Ks3Oss:
             return None
 
     def modify_object(self, bucket_name=None, *args, **kwargs):
-        if self.instance is None:
+        if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         return self.instance.copy_key(*args, **kwargs)
