@@ -208,3 +208,42 @@ def nacos_post(path, data=None, service_name=None, namespace="public", clusters=
 
     res = sync_post(path=path, data=data, base_url=base_url, result_type=return_type, pack=pack, **kwargs)
     return res
+
+
+def common_get(path, params=None, service_name=None, namespace="public", clusters=None, group_name=None,
+               pack=False, return_type="json", **kwargs):
+    base_url = tornado.options.options.data_server
+    if kwargs.get("base_url") is not None:
+        base_url = kwargs.pop("base_url")
+    if tornado.options.options.request_type == "request":
+        res = sync_get(path=path, params=params, base_url=base_url, result_type=return_type, pack=pack, **kwargs)
+        return res
+    elif tornado.options.options.request_type == "eureka":
+        res = eureka_get(path=path, data=params, return_type=return_type, app_name=service_name, pack=pack, **kwargs)
+        return res
+    elif tornado.options.options.request_type == "nacos":
+        res = nacos_get(path=path, params=params, service_name=service_name, namespace=namespace, clusters=clusters,
+                        group_name=group_name, pack=pack, return_type=return_type, **kwargs)
+        return res
+    else:
+        raise BusinessException(StatusCode.UNSUPPORTED_REQUEST_TYPE)
+
+
+def common_post(path, data=None, service_name=None, namespace="public", clusters=None, group_name=None,
+                pack=False, return_type="json", **kwargs):
+    base_url = tornado.options.options.data_server
+    if kwargs.get("base_url") is not None:
+        base_url = kwargs.pop("base_url")
+    if tornado.options.options.request_type == "request":
+        res = sync_post(path=path, data=data, base_url=base_url, result_type=return_type, pack=pack, **kwargs)
+        return res
+    elif tornado.options.options.request_type == "eureka":
+        res = eureka_post(path=path, data=data, return_type=return_type, app_name=service_name, pack=pack, **kwargs)
+        return res
+    elif tornado.options.options.request_type == "nacos":
+        res = nacos_post(path=path, data=data, service_name=service_name, namespace=namespace, clusters=clusters,
+                         group_name=group_name,
+                         pack=pack, return_type=return_type, **kwargs)
+        return res
+    else:
+        raise BusinessException(StatusCode.UNSUPPORTED_REQUEST_TYPE)
